@@ -16,7 +16,7 @@
 // kdecore
 #include <KConfigGroup>
 #include <KSharedConfig>
-#ifdef QT_DBUS_LIB
+#ifdef WITH_QTDBUS
 #include <QDBusConnection>
 #include <QDBusMessage>
 #endif
@@ -156,22 +156,27 @@ public:
             parseGenericIconsFiles(file);
         }
 
-#ifdef QT_DBUS_LIB
-        QDBusConnection::sessionBus().connect(QString(),
-                                              QStringLiteral("/KIconLoader"),
-                                              QStringLiteral("org.kde.KIconLoader"),
-                                              QStringLiteral("iconChanged"),
-                                              this,
-                                              SIGNAL(iconChanged(int)));
+#ifdef WITH_QTDBUS
+        if (QDBusConnection::sessionBus().interface()) {
+            QDBusConnection::sessionBus().connect(QString(),
+                                                  QStringLiteral("/KIconLoader"),
+                                                  QStringLiteral("org.kde.KIconLoader"),
+                                                  QStringLiteral("iconChanged"),
+                                                  this,
+                                                  SIGNAL(iconChanged(int)));
+        }
 #endif
     }
 
     void emitChange(KIconLoader::Group group)
     {
-#ifdef QT_DBUS_LIB
-        QDBusMessage message = QDBusMessage::createSignal(QStringLiteral("/KIconLoader"), QStringLiteral("org.kde.KIconLoader"), QStringLiteral("iconChanged"));
-        message.setArguments(QList<QVariant>() << int(group));
-        QDBusConnection::sessionBus().send(message);
+#ifdef WITH_QTDBUS
+        if (QDBusConnection::sessionBus().interface()) {
+            QDBusMessage message =
+                QDBusMessage::createSignal(QStringLiteral("/KIconLoader"), QStringLiteral("org.kde.KIconLoader"), QStringLiteral("iconChanged"));
+            message.setArguments(QList<QVariant>() << int(group));
+            QDBusConnection::sessionBus().send(message);
+        }
 #endif
     }
 
